/***************************************************************************//**
 *   @file   AD5172.c
 *   @brief  Implementation of AD5172 Driver.
 *   @author Dan Nechita
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 610
*******************************************************************************/

/******************************************************************************/
/* Include Files                                                              */
/******************************************************************************/
#include "AD5172.h"			    // AD5172 definitions.
#include "Communication.h"		// Communication definitions.

/**************************************************************************//**
 * @brief 
 *
 * @return 1.
*******************************************************************************/
unsigned char AD5172_Init(void)
{  
    I2C_Init(100000);
    return(1);    
}

/**************************************************************************//**
 * @brief Sets or clears the Shutdown bit.
 *
 * @param channel - The channel to be shutdown.
 *                  Example: 0 - channel 1    
 *                           1 - channel 2
 * @param flag - Sets or clears the Shutdown bit.
 *               Example: 1 - sets the bit
 *                        0 - clears the bit
 *
 * @return None.
*******************************************************************************/
void AD5172_Shutdown(unsigned char channel, 
                     unsigned char flag)
{
	unsigned char i2cWord = 0x00;
    
    i2cWord = (channel << 7) | (AD5172_SD * flag);
    I2C_Write(AD5172_DEVICE_ADDR, (unsigned char*)&i2cWord, 1, 1);
}

/**************************************************************************//**
 * @brief The channel is being one-time programmed(OTP).
 *
 * @param channel - The channel to be written.
 *                  Example: 0 - channel 1    
 *                           1 - channel 2
 * @param data - Data to be written into a channel.
 *
 * @return None.
*******************************************************************************/
void AD5172_Otp(unsigned char channel, unsigned char data)
{
    unsigned char i2cWord[2] = {0x00, 0x00};
    
    i2cWord[0] = (channel << 7) | AD5172_T | AD5172_OW;
    i2cWord[1] = data;
    I2C_Write(AD5172_DEVICE_ADDR, i2cWord, 2, 1);
}

/**************************************************************************//**
 * @brief Send data to one of the 2 channels available.
 *
 * @param channel - The channel to be written.
 *                  Example: 0 - channel 1    
 *                           1 - channel 2
 * @param data - Data to be written into a channel.
 *                               
 * @return None.
*******************************************************************************/
void AD5172_WriteRDAC(unsigned char channel, 
                      unsigned char data)
{
    unsigned char i2cWord[2] = {0x00, 0x00};
    
    i2cWord[0] = (channel << 7) | AD5172_OW;
    i2cWord[1] = data;
    I2C_Write(AD5172_DEVICE_ADDR, i2cWord, 2, 1);
}

/**************************************************************************//**
 * @brief Reads a byte form the selected channel.
 *
 * @param channel - The channel to be read.
 *                  Example: 0 - channel 1    
 *                           1 - channel 2
 * 
 * @return dataRead - Data read from a channel.
*******************************************************************************/
unsigned char AD5172_ReadRDAC(unsigned char channel)
{
    unsigned char i2cWord[2] = {0x00, 0x00};
    unsigned char dataRead = 0;

    i2cWord[0] = (channel & 0x01) << 7; 
	/* Sets the selected channel to write mode so that the subsequent reading
	will be for that channel. */
    I2C_Write(AD5172_DEVICE_ADDR, i2cWord, 1, 0);                                                                      
    i2cWord[0] = 0xFF;
    I2C_Read(AD5172_DEVICE_ADDR, i2cWord, 2, 1);
    dataRead = i2cWord[0];
	
    return(dataRead);
}
